@@ -77,6 +77,7 @@ class Compress(object):
             ('COMPRESS_CACHE_KEY', None),
             ('COMPRESS_CACHE_BACKEND', None),
             ('COMPRESS_REGISTER', True),
+            ('COMPRESS_STREAMS', True),
             ('COMPRESS_ALGORITHM', ['br', 'gzip', 'deflate']),
         ]
 
@@ -178,7 +179,7 @@ class Compress(object):
             response.mimetype not in app.config["COMPRESS_MIMETYPES"] or
             response.status_code < 200 or
             response.status_code >= 300 or
-            response.is_streamed or
+            (response.is_streamed and app.config["COMPRESS_STREAMS"] is False)or
             "Content-Encoding" in response.headers or
             (response.content_length is not None and
              response.content_length < app.config["COMPRESS_MIN_SIZE"])):
